pub struct Proof {
pub signers: Vec<ProofSigner>,
pub threshold: u128,
pub nonce: BytesN<32>,
}Expand description
Proof represents a proof that a set of signers have signed a message.
All weighted signers are included in the along with a signature, if they have signed the message,
until threshold is met.
Fields
signers: Vec<ProofSigner>threshold: u128nonce: BytesN<32>Implementations
Sourceimpl Proof
impl Proof
Sourcepub fn weighted_signers(&self) -> WeightedSigners
pub fn weighted_signers(&self) -> WeightedSigners
Get the weighted signers from the proof.