pub struct AxelarExecutableClient<'a> {
pub env: Env,
pub address: Address,
/* private fields */
}Expand description
AxelarExecutableClient is a client for calling the contract defined in “AxelarExecutableInterface”.
Fields
env: Envaddress: AddressImplementations
Sourceimpl<'a> AxelarExecutableClient<'a>
impl<'a> AxelarExecutableClient<'a>
Sourcepub fn try_gateway(
&self,
) -> Result<Result<Address, <Address as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_gateway( &self, ) -> Result<Result<Address, <Address as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Return the trusted gateway contract id.
Sourcepub fn execute(
&self,
source_chain: &String,
message_id: &String,
source_address: &String,
payload: &Bytes,
)
pub fn execute( &self, source_chain: &String, message_id: &String, source_address: &String, payload: &Bytes, )
Execute a cross-chain contract call with the given payload. This function must validate that the contract call is received from the trusted gateway.
Sourcepub fn try_execute(
&self,
source_chain: &String,
message_id: &String,
source_address: &String,
payload: &Bytes,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_execute( &self, source_chain: &String, message_id: &String, source_address: &String, payload: &Bytes, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Execute a cross-chain contract call with the given payload. This function must validate that the contract call is received from the trusted gateway.
Sourcepub fn validate(
&self,
source_chain: &String,
message_id: &String,
source_address: &String,
payload: &Bytes,
)
pub fn validate( &self, source_chain: &String, message_id: &String, source_address: &String, payload: &Bytes, )
Validate if a gateway has approved a contract call.
This should be called from an implementation of execute before executing custom app logic.
This method doesn’t get exposed from the contract, as Soroban SDK’s contractimpl macro ignores default trait methods.
Sourcepub fn try_validate(
&self,
source_chain: &String,
message_id: &String,
source_address: &String,
payload: &Bytes,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_validate( &self, source_chain: &String, message_id: &String, source_address: &String, payload: &Bytes, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Validate if a gateway has approved a contract call.
This should be called from an implementation of execute before executing custom app logic.
This method doesn’t get exposed from the contract, as Soroban SDK’s contractimpl macro ignores default trait methods.